@@ -3,7 +3,7 @@ package Firefox::Marionette::Proxy;
 use strict;
 use warnings;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 sub new {
     my ( $class, %parameters ) = @_;
@@ -68,7 +68,7 @@ Firefox::Marionette::Proxy - Represents a Proxy used by Firefox Capabilities usi
 
 =head1 VERSION
 
-Version 0.41
+Version 0.42
 
 =head1 SYNOPSIS
 
@@ -95,7 +95,7 @@ accepts a hash as a parameter.  Allowed keys are below;
 
 =item * type - indicates the type of proxy configuration.  Must be one of 'pac', 'direct', 'autodetect', 'system', or 'manual'.
 
-=item * pac - defines the L<URI|URI> for a proxy auto-config file if the <type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
+=item * pac - defines the L<URI|URI> for a proxy auto-config file if the L<type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
 
 =item * http - defines the proxy host for HTTP traffic when the L<type|Firefox::Marionette::Proxy#type> is 'manual'.
 
@@ -119,7 +119,7 @@ returns the type of proxy configuration.  Must be one of 'pac', 'direct', 'autod
 
 =head2 pac
 
-returns the L<URI|URI> for a proxy auto-config file if the <type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
+returns the L<URI|URI> for a proxy auto-config file if the L<type|Firefox::Marionette::Proxy#type> is equal to 'pac'.
 
 =head2 http
 
